use async_trait::async_trait;
use reqwest::Method;
use serde::{Deserialize, Serialize};

pub mod app;
pub mod element;
pub mod events;

/// Any struct defining a request body for the ubisync API must implement this trait
/// It is used both by the client in the SDK and by the API logic in the ubisync node
#[async_trait]
pub trait UbisyncRequest: for<'de> Deserialize<'de> + Serialize {
    type PathParameters;
    type Response: for<'de> Deserialize<'de> + Serialize;

    fn method(&self) -> Method;
    fn path(&self, params: Self::PathParameters) -> String;
    async fn parse_response(resp: reqwest::Response) -> Result<Self::Response, reqwest::Error>
    where
        for<'de> <Self as UbisyncRequest>::Response: Deserialize<'de>,
    {
        resp.json().await
    }
}
