use serde::{Deserialize, Serialize};

use super::{ElementContent, ElementId, MessageId, PotId};

#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub struct Element {
    // Uuid identifying the element itself
    pub id: ElementId,
    pub pot: Option<PotId>,
    pub content: ElementContent,
    pub update_strategy: ElementUpdateStrategy,
    pub latest_message: Option<MessageId>,
    pub local_changes: bool,
}

impl Element {
    pub fn new(id: ElementId, content: ElementContent, update_strategy: ElementUpdateStrategy) -> Self {
        // A new element with no latest message must have local changes
        Element {
            id: id,
            pot: None,
            content,
            update_strategy,
            latest_message: None,
            local_changes: true,
        }
    }

    pub fn id(&self) -> &ElementId {
        &self.id
    }
    pub fn content(&self) -> &ElementContent {
        &self.content
    }
    pub fn pot(&self) -> &Option<PotId> {
        &self.pot
    }
    pub fn latest_message(&self) -> &Option<MessageId> {
        &self.latest_message
    }
    pub fn local_changes(&self) -> bool {
        self.local_changes
    }
}



#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub enum ElementUpdateStrategy {
    Overwrite
}