use tracing::debug;

use ubisync_lib::peer::Peer;
use ubisync_lib::types::PeerId;

use ubisync_lib::messages::{Message, MessageContent};

use crate::state::CommState;

pub fn handle(state: &CommState, peer: &PeerId, message: Message) {
    debug!("Handling message now: {:?}", message);
    match message.content() {
        MessageContent::Hello { peer_name } => {
            state
                .set_peer(Peer::new(peer.to_owned(), Some(peer_name.to_string())))
                .expect("State failed");
        }
        MessageContent::CreateElement { id, content, pot } => {
            state
                .add_received_element(
                    id.to_owned(),
                    content.to_owned(),
                    Some(message.id().to_owned()),
                    pot.to_owned(),
                )
                .expect("State failed");
        }
        MessageContent::UpdateElement { id, content } => {
            state
                .update_element_content(id.to_owned(), content.to_owned(), message.id().to_owned())
                .expect("State failed");
        }
        MessageContent::RemoveElement { id } => {
            state.remove_element(id.to_owned()).expect("State failed");
        }
        MessageContent::AddPot { id, app_type } => {
            state
                .add_pot(id.to_owned(), app_type.to_string())
                .expect("State failed");
        }
    }
}
